@@ -13,12 +13,13 @@ from ._pydantic_core import (
     __version__,
     to_json,
 )
-from .core_schema import CoreConfig, CoreSchema
+from .core_schema import CoreConfig, CoreSchema, CoreSchemaType
 
 __all__ = (
     '__version__',
     'CoreConfig',
     'CoreSchema',
+    'CoreSchemaType',
     'SchemaValidator',
     'SchemaSerializer',
     'Url',
