@@ -30,7 +30,7 @@ impl BuildValidator for TimeValidator {
     fn build(
         schema: &PyDict,
         config: Option<&PyDict>,
-        _build_context: &mut BuildContext,
+        _build_context: &mut BuildContext<CombinedValidator>,
     ) -> PyResult<CombinedValidator> {
         let py = schema.py();
         let has_constraints = schema.get_item(intern!(py, "le")).is_some()
