@@ -189,7 +189,7 @@ def test_ser_function_plain():
     )
     assert s.to_python(123) == (
         "SerializationInfo(include=None, exclude=None, mode='python', by_alias=True, exclude_unset=False, "
-        "exclude_defaults=False, exclude_none=False, round_trip=False)"
+        'exclude_defaults=False, exclude_none=False, round_trip=False)'
     )
 
 
@@ -204,7 +204,7 @@ def test_ser_function_wrap():
     )
     # insert_assert(s.to_python(123, mode='json'))
     assert s.to_python(123, mode='json') == (
-        "SerializationCallable(serializer=str) "
+        'SerializationCallable(serializer=str) '
         "SerializationInfo(include=None, exclude=None, mode='json', by_alias=True, exclude_unset=False, "
-        "exclude_defaults=False, exclude_none=False, round_trip=False)"
+        'exclude_defaults=False, exclude_none=False, round_trip=False)'
     )
