@@ -12,10 +12,10 @@ def test_nullable():
         v.validate_python('hello')
     assert exc_info.value.errors() == [
         {
-            'kind': 'int_parsing',
-            'loc': [],
-            'message': 'Input should be a valid integer, unable to parse string as an integer',
-            'input_value': 'hello',
+            'type': 'int_parsing',
+            'loc': (),
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
+            'input': 'hello',
         }
     ]
 
